// Test application using awt library
// Neuron Computing Inc.

#include "awt/Dlg_Common.h"
#include "awt/Toolkit.h"

#include <stdio.h>
#include <stdlib.h>

extern "C" void mainCRTStartup();

extern "C" void WinMainCRTStartup()
{
	mainCRTStartup();
}

// Menu
static char* s_menu_items[] = {
	// 1
	"Edit Dialog...",
	"Info Dialog...",
	"Single List Dialog...",
	"",
	// 5
	"Select Font...",
	"File List...",
	"File Dialog...",
	"",
	// 9
	"Toggle Grid",
	"Clear All",
	"Quit"
};

int s_menu_item_count = sizeof(s_menu_items)/sizeof(char*);

static char* s_menu_title = "Test X Widgets";

// Main
XApp* g_app  = NULL;

// TestFrame
class TestFrame : public Frame
{
public:
	int m_countPt;
	Point m_pt[10];

	Bool m_showGrid;

	char m_text[256];

TestFrame()
{
	m_countPt = 0;
	m_showGrid = TRUE;
}

~TestFrame()
{
}

void paintGrid(Graphics* g)
{
	DimensionOb* dim = getSize();
	Color c = getForeground();
	g->setColor(c);
	g->drawRect(0, 0, dim->width-1, dim->height-1);

	Color colorGrid(160, 160, 160);
	g->setColor(colorGrid);
	for (int k=20; k<=600; k+=20)
	{
		g->drawLine(0, k, 600, k);
		g->drawLine(k, 0, k, 600);
	}

	g->setColor(c);
	delete dim;
}

void paint(Graphics* g)
{
	// Paint grid
	if (m_showGrid)
		paintGrid(g);

	// Paint mouse clicks
    for (int i=0; i<m_countPt; i++)
	{
		Point& pt = m_pt[i];
        g->drawLine(pt.x, pt.y, pt.x+10, pt.y+10);
        char buf[22];
        sprintf(buf, "%d",i);
        g->drawString(pt.x, pt.y - 15, buf);
    }
    // Draw text
    g->drawString(40, 60, m_text);
}

void mouseDown(int x, int y)
{
    if (m_countPt < 9)
	{
        m_pt[m_countPt].x = x;
        m_pt[m_countPt].y = y;
        m_countPt++;
    }
}

void actionPerformed(int id)
{
	switch (id)
	{
	case 1:
	{
		sprintf(m_text, "This is a test.");
		Dlg_Edit dlg;
		dlg.m_parent = m_w;
		dlg.do_edit("Prompt:", m_text);
		break;
	}
	case 2:
	{
		Dlg_Info dlg;
		dlg.m_parent = m_w;
		dlg.show_info("Test application...");
		break;
	}
    case 3:
	{
		static char* s_sel_list[] = {
			"item 0",
			"item 1",
			"item 2",
			"item 3"
		};

		Dlg_List dlg;
		dlg.m_parent = m_w;
		int ii = dlg.choose_one_from_list("List Dialog", s_sel_list, 4);

		char buffer[255];
		sprintf(buffer, "Item selected = %d", ii);
		::messageBox(buffer);
		break;
	}
	//
	case 5:
	{
		Dlg_ChooseFont dlg;
		dlg.m_parent = m_w;
		int result = dlg.choose_font();
		break;
	}
	case 6:
	{
		Dlg_File dlg;
		dlg.m_parent = m_w;
		char szFileName[256];
		int result = dlg.choose_file_to_read("Open File", "", szFileName);
		break;
	}
	case 7:
	{
		FileDialog dlg;
		dlg.create(m_w);
		dlg.doModal();
		break;
	}
	//
	case 9:
		m_showGrid = ~m_showGrid;
		repaint(0);
		break;
	case 10:
		m_countPt = 0;
		repaint(0);
		break;
	case 11:
		exit(0);
		break;
	}
}
};

// main
int main(int argc, char **argv)
{
	XApp app;
	g_app = &app;

	app.init(argc, argv);
	TestFrame* mainFrame = new TestFrame();
	app.setMainFrame(mainFrame);
	mainFrame->setMenuBar(s_menu_title, s_menu_items, s_menu_item_count);
	mainFrame->setBounds(40, 40, 420, 380);
	Rectangle* r = mainFrame->getBounds();
	if (r = NULL)
		delete r;
	int height = mainFrame->getHeight();
	app.run();
}
